"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sendCreateMesage = exports.sendMessage = exports.digestHash = exports.signMessage = void 0;
const crypto = require("node:crypto");
const axios_1 = require("axios");
const SigUtils = require("./signature");
const signMessage = async (message) => {
    const pem = SigUtils.Bytes.fromBase64(process.env.PRIVATE_KEY).utf8();
    const key = await SigUtils.importKeyFromPem(pem, "private");
    return await SigUtils.signMessage(key, message);
};
exports.signMessage = signMessage;
const digestHash = async (message) => {
    const hash = crypto.createHash('sha256');
    hash.update(JSON.stringify(message));
    return hash.digest('base64');
};
exports.digestHash = digestHash;
const sendMessage = async (message, sender, target) => {
    const inbox = `${target.actor}/inbox`;
    const inboxFragment = inbox.replace(`https://${target.domain}`, '');
    const date = new Date();
    const hash = await (0, exports.digestHash)(message);
    const stringToSign = `(request-target): post ${inboxFragment}\nhost: ${target.domain}\ndate: ${date.toUTCString()}\ndigest: SHA-256=${hash}`;
    const signature = await (0, exports.signMessage)(stringToSign);
    const header = `keyId="https://${sender.domain}/${sender.actor}",headers="(request-target) host date digest",signature="${signature}"`;
    const headers = {
        "Signature": header,
        "Host": target.domain,
        'Digest': `SHA-256=${hash}`,
        "Date": date.toUTCString(),
    };
    const options = {
        headers,
        method: "POST",
        body: JSON.stringify(message)
    };
    return await axios_1.default.post(inbox, JSON.stringify(message), {
        headers,
    });
};
exports.sendMessage = sendMessage;
const sendCreateMesage = async (sender, target, object) => {
    const uuid = crypto.randomUUID();
    const createMessage = {
        "@context": "https://www.w3.org/ns/activitystreams",
        "id": `https://${sender.domain}/${sender.actor}/${uuid}`,
        "type": "Create",
        "actor": `https://${sender.domain}/${sender.actor}`,
        'to': ['https://www.w3.org/ns/activitystreams#Public'],
        object,
        "cc": [target.actor]
    };
    return await (0, exports.sendMessage)(createMessage, sender, target);
};
exports.sendCreateMesage = sendCreateMesage;
